@@ -1,6 +1,7 @@
 from pathlib import Path
 
-VERSION = '1.1.3'
+# If cloud has been updated with required changes, please updated REQUIRES_CLI_VERSION in figtools/figgy
+VERSION = '1.2.1'
 CLI_NAME = 'figgy'
 PROJECT_NAME = 'figgy'
 
@@ -23,6 +24,7 @@ BREW_FORMULA = 'figtools/figgy/figgy'
 # Role names are assumed to be prefixed with `figgy-` - Users may override by setting the below ENV variable.
 FIGGY_ROLE_NAME_PREFIX = 'figgy-'
 FIGGY_ROLE_PREFIX_OVERRIDE_ENV = 'FIGGY_ROLE_PREFIX_OVERRIDE'
+FIGGY_DEFAULT_ROLE_NAME = 'figgy-default'
 
 # Table-specific Constants
 REPL_TABLE_NAME = "figgy-config-replication"
@@ -84,6 +86,11 @@ PS_FIGGY_DEFAULT_SERVICE_NS_PATH = '/figgy/defaults/service-namespace'
 PS_FIGGY_REPL_KEY_ID_PATH = '/figgy/kms/replication-key-id'
 PS_FIGGY_ALL_KMS_KEYS_PATH = '/figgy/kms/all-keys'
 PS_FIGGY_REGIONS = '/figgy/regions'
+PS_FIGGY_UTILITY_ACCOUNT_ID = '/figgy/utility-account-id'
+PS_FIGGY_OTS_KEY_ID = '/figgy/kms/figgy-ots-key-id'
+PS_FIGGY_ENV_ALIAS = '/figgy/env_alias'
+PS_FIGGY_CURRENT_ACCOUNT_ID = '/figgy/account_id'
+PS_CLOUD_VERSION_PATH = '/figgy/cloud/version'
 
 # Replication Types:
 repl_types = [REPL_TYPE_APP, REPL_TYPE_MERGE]
@@ -149,6 +156,7 @@ figgy_ns = '/figgy'
 
 # PS PATHS:
 ACCOUNT_ID_PATH = f'{figgy_ns}/account_id'
+REGION_PATH = f'{figgy_ns}/region'
 
 # Vault
 FIGGY_VAULT_FILES = [OKTA_SESSION_CACHE_PATH, GOOGLE_SESSION_CACHE_PATH, STS_SESSION_CACHE_PATH, SAML_SESSION_CACHE_PATH]
